const path = require('path'),
	MiniCssExtractPlugin = require('mini-css-extract-plugin'),
	CopyWebpackPlugin = require('copy-webpack-plugin'),
	module1 = require('./webpack.config');

module.exports = Object.assign({}, module1, {
	mode: 'production',
	output: {
		path: path.resolve(__dirname, 'dist'),
	},
	module: {
		rules: [{
			test: /\.js$/,
			include: [
				path.resolve(__dirname, 'js')
			],
			exclude: /node_modules/,
			use: {
				loader: 'babel-loader',
				options: {
					presets: ['env']
				}
			}
		},
		{
			test: /\.(scss)$/,
			use: [{
				loader: MiniCssExtractPlugin.loader,
			}, {
				loader: 'css-loader',
			}, {
				loader: 'postcss-loader',
				options: {
					plugins: function () {
						return [
							require('precss'),
							require('autoprefixer'),
							require('postcss-clean')
						];
					}
				}
			}, {
				loader: 'sass-loader'
			}]
		}
		]
	},
	plugins: [
		new MiniCssExtractPlugin({
			path: path.resolve(__dirname, 'dist'),
		}),
		new CopyWebpackPlugin({
			patterns: [
				{
					from: 'assets',
					transform(content, absoluteFrom) {
						if (absoluteFrom.endsWith('azure-upload-settings.json')) {
							let bumpVersion = require('./package.json').version,
								value = content.toString('utf8')
							return value.replace('v0.0.0', `v${bumpVersion}`)
						} else {
							return content
						}
					},
				}
			]
		})
	]
});
